@@ -7,7 +7,7 @@ use Exporter;
 
 require DynaLoader;
 
-$VERSION = 0.09;
+$VERSION = "0.10";
 @ISA = qw(Exporter DynaLoader);
 @EXPORT_OK = ();
 %EXPORT_TAGS = (
@@ -77,6 +77,14 @@ sub new {
 	my $options = (exists $self->{Options})
 					? $self->{Options}
 					: { };
+	if (exists $options->{Define}) {
+		# Convert defined macros into a canonical form.
+		if (ref($options->{Define}) eq 'HASH') {
+			my %opts = %{ $options->{Define} };
+			$options->{Define} = [ map { "$_=$opts{$_}" } keys %opts ];
+		}
+	}
+
 	return Text::CPP::_create($class, $language, $builtins, $options);
 }
 
@@ -89,6 +97,9 @@ Text::CPP - A full C Preprocessor in XS
 	use Text::CPP;
 	my $reader = new Text::CPP(
 		Language	=> CLK_GNUC99,
+		Options		=> {
+			...
+		},
 		Builtins	=> {
 			foo	=> 'this',
 			bar	=> 'that',
@@ -152,7 +163,7 @@ with alternative forms (from GNU cpp) in brackets.
 
 =over 4
 
-=item Define (-D): array of strings
+=item Define (-D): array of strings or hash
 
 Strings should be of the form NAME=VALUE.
 
@@ -235,7 +246,9 @@ This include path is searched after the system include path.
 =item Builtins
 
 A hashref of predefined macros. The values must be strings or integers.
-Macros in this hash will be defined before preprocessing starts.
+Macros in this hash will be defined before preprocessing starts. These
+correspond to true "builtin" macros. You should probably prefer to
+use the 'Define' option.
 
 =back
 
@@ -277,8 +290,10 @@ the warnings.
 
 =head1 BUGS
 
-This documentation is incomplete. There are many important functions
-in the source which are not yet documented.
+Fewer than in the last release, and hopefully not very many.
+
+This documentation is probably incomplete. There are many important
+functions in the source which are not yet documented.
 
 It is not possible to instantiate multiple Text::CPP objects, since
 the underlying library uses many global variables.
@@ -286,24 +301,7 @@ the underlying library uses many global variables.
 C99 may not implement variadic macros correctly according to the ISO
 standard. I must check this. If anyone knows, please tell me.
 
-It is not yet possible to specify a list of include directories.
-
-The code is still tied into gcc in some places. Files like prefix.c
-can be removed entirely when this is cleaned up.
-
-The following options are not yet handled.
-
-=item -M*
-
-=item -std
-
-=item -ansi
-
-=item -foperator-names
-
-=item -fshow-column
-
-=item -ftabstop
+The -M option is not yet handled.
 
 =head1 CAVEATS
 
@@ -323,14 +321,23 @@ It does not seem necessary to support the following flags:
 
 =item -fpreprocessed
 
+The following options may be requested, but seem boring, so are not
+currently supported.
+
+=item -std
+
+=item -ansi
+
+=item -foperator-names
+
+=item -fshow-column
+
+=item -ftabstop
+
 =head1 TODO
 
-=item Include lists
-
 =item Dependency output
 
-=item Support remaining options
-
 =item Lots more tests
 
 =item Remaining callbacks
